NABQR package
=============


NABQR.functions  
----------------------

.. automodule:: NABQR.functions
   :members:
   :undoc-members:
   :show-inheritance:

NABQR.functions\_for\_TAQR 
---------------------------------

.. automodule:: NABQR.functions_for_TAQR
   :members:
   :undoc-members:
   :show-inheritance:

NABQR.helper\_functions  
------------------------------

.. automodule:: NABQR.helper_functions
   :members:
   :undoc-members:
   :show-inheritance:

NABQR.nabqr  
------------------

.. automodule:: NABQR.nabqr
   :members:
   :undoc-members:
   :show-inheritance:

NABQR.visualization  
--------------------------

.. automodule:: NABQR.visualization
   :members:
   :undoc-members:
   :show-inheritance:


